.. image:: https://rubika.ir/static/images/logos/verticla-collorfull/vertical-colorful.png
    :align: left
    :target: https://rubika.ir/rubim_py
    :alt: Rubika
    :height: 240
    

Rubika:
=======

 [</>] - `Creator ID in Rubika <https://rubika.ir/mmdreza_2721>`_

 [</>] - `Channel in Rubika <https://rubika.ir/rubim_py>`_

Subscribe to the channels to know about the library and sources updates.

Installing rubim from PyPI
--------------------------

.. code-block:: python3

    pip install rubim
..


* if you have a problem with the installation, subscribe to the channel.

import rubim
===================

.. code-block:: python3

    from rubim import rubino

    bot = rubino('auth')


Why Rubim ?
-----------

* *Having all the methods of Rubino*
* *Simple and complete document*
* *Appropriate speed*
